/*
 * Gksu -- a library providing access to su functionality
 * Copyright (C) 2004 Gustavo Noronha Silva
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "gksu.h"

gboolean
su_ask_pass (GksuContext *context, gchar *prompt, gpointer data, GError **error)
{
  char *password;

  password = getpass (prompt);
  gksu_context_set_password (context, password);

  return 0;
}

void
password_not_needed (GksuContext *context, gpointer data)
{
  fprintf (stderr, "Will run %s as %s!\n", context->command, context->user);
}

int
main (int argc, char **argv)
{
  GksuContext *context;
  GError *error = NULL;
  char *password;
  gboolean try_su = TRUE;
  gboolean try_sudo = TRUE;

  if (argc > 1)
    {
      if (!strcmp (argv[1], "--su"))
	try_sudo = FALSE;
      else if (!strcmp (argv[1], "--sudo"))
	try_su = FALSE;
    }

  context = gksu_context_new ();

  gksu_context_set_debug (context, TRUE);
  gksu_context_set_command (context, "/usr/bin/X11/xterm");

  if (try_su)
    {
      if (gksu_context_try_need_password (context))
	{
	  password = getpass ("Type the root password: ");
	  gksu_context_set_password (context, password);
	}
      
      printf ("Testing gksu_run...\n");
      gksu_context_run (context, &error);
      if (error)
	fprintf (stderr, "gksu_run failed: %s\n", error->message);

      gksu_context_set_password (context, NULL);
      printf ("Testing gksu_ask_and_run...\n");
      gksu_context_run_full (context, su_ask_pass, NULL, 
			     password_not_needed, NULL, 
			     &error);
      gksu_context_set_password (context, NULL);
    }
  
  if (try_sudo)
    {
      error = NULL;
      /* sudo may already have my authorization */
      if (gksu_context_sudo_try_need_password (context))
	{
	  password = NULL;
	  password = getpass ("Type your password(sudo): ");
	  gksu_context_set_password (context, password);
	}
      
      /* of course you need to set up /etc/sudoers for this to work */
      printf ("Testing gksu_sudo_run...\n");
      error = NULL;
      gksu_context_sudo_run (context, &error);
      if (error)
	fprintf (stderr, "gksu_run failed: %s\n", error->message);

      error = NULL;
      gksu_context_set_password (context, NULL);
      gksu_context_sudo_run_full (context, su_ask_pass, NULL, 
				  password_not_needed, NULL, 
				  &error);
      if (error)
	fprintf (stderr, "gksu_run failed: %s\n", error->message);
    }
      
  return 0;
}

